.. _content-projects:

========
Projects
========

The Jupyter community is composed of several sub-communities and projects. These
are organized around particular use-cases, users, or other aspects of the Jupyter
community. This section contains information to help navigate these projects
both from the perspective of a user and a community member.

Jupyter Projects and Communities
================================

Information relevant to understanding the many projects in the Jupyter ecosystem,
including their technical components and how they work and relate to one another.


.. toctree::
   :maxdepth: 1

   user-interfaces
   kernels
   education
   execution
   deployment
   conversion
   ipython_projects
   core
   incubator


More information
================

.. toctree::
   :maxdepth: 2

   architecture/content-architecture
   doc-proj-categories
   /releases
